<?php

namespace Drupal\aritic\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\UrlHelper;

/**
 * Configure Aritic settings for this site.
 */
class AriticAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'aritic_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['aritic.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('aritic.settings');

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
    ];

    $form['general']['aritic_enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Include Aritic Javascript Code'),
      '#default_value' => $config->get('aritic_enable'),
      '#description' => $this->t("If you want to embed the Aritic Javascript Code, enable this check."),
      '#required' => FALSE,
    ];

    $form['general']['aritic_base_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Aritic URL'),
      '#default_value' => $config->get('aritic_base_url'),
      '#states' => [
        'visible' => [
          ':input[name="aritic_enable"]' => ['checked' => TRUE],
        ],
      ],
      '#size' => 60,
      '#description' => $this->t("Your Aritic javascript code. Example: http(s)://youraritic.com/ma/atc.js"),
      '#required' => TRUE,
    ];

    $form['tracking_page'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Tracking Page'),
    ];

    $aritic_pages_list = $config->get('visibility.request_path_pages');

    $form['tracking']['page_visibility_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Pages'),
      '#group' => 'tracking_page',
    ];

    if ($config->get('visibility.request_path_mode') == 2) {
      $form['tracking']['page_visibility_settings'] = [];
      $form['tracking']['page_visibility_settings']['aritic_visibility_request_path_mode'] = ['#type' => 'value', '#value' => 2];
      $form['tracking']['page_visibility_settings']['aritic_visibility_request_path_pages'] = ['#type' => 'value', '#value' => $aritic_pages_list];
    }
    else {
      $options = [
        $this->t('Every page except the listed pages'),
        $this->t('The listed pages only'),
      ];
      $description = $this->t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.",
        [
          '%blog' => '/blog',
          '%blog-wildcard' => '/blog/*',
          '%front' => '<front>',
        ]
      );
      $title = $this->t('Pages');
      $form['tracking']['page_visibility_settings']['aritic_visibility_request_path_mode'] = [
        '#type' => 'radios',
        '#title' => $this->t('Add tracking to specific pages'),
        '#options' => $options,
        '#default_value' => $config->get('visibility.request_path_mode'),
      ];
      $form['tracking']['page_visibility_settings']['aritic_visibility_request_path_pages'] = [
        '#type' => 'textarea',
        '#title' => $title,
        '#title_display' => 'invisible',
        '#default_value' => !empty($aritic_pages_list) ? $aritic_pages_list : "/admin\n/admin/*\n/batch\n/node/add*\n/node/*/*\n/user/*/*",
        '#description' => $description,
        '#rows' => 10,
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);

    $url_is_valid = UrlHelper::isValid($form_state->getValue('aritic_base_url'), $absolute = TRUE);

    // Check if is a valid url.
    if (!$url_is_valid) {
      $form_state->setErrorByName('aritic_base_url', $this->t('The URL is not valid.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('aritic.settings');
    $config
      ->set('aritic_enable', $form_state->getValue('aritic_enable'))
      ->set('aritic_base_url', $form_state->getValue('aritic_base_url'))
      ->set('visibility.request_path_mode', $form_state->getValue('aritic_visibility_request_path_mode'))
      ->set('visibility.request_path_pages', $form_state->getValue('aritic_visibility_request_path_pages'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
